==> gnucash-2.2.9-i486-1sys.tgz: install/doinst.sh <==
if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database /usr/share/mime &> /dev/null
fi

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database 1> /dev/null &> /dev/null
fi

if [ -x /usr/bin/gtk-update-icon-cache ]; then
  /usr/bin/gtk-update-icon-cache  -f -q /usr/share/icons/hicolor &> /dev/null
fi

#
( cd usr/lib ; rm -rf libgnc-business-ledger.so.0 )
( cd usr/lib ; ln -sf libgnc-business-ledger.so.0.0.0 libgnc-business-ledger.so.0 )
( cd usr/lib ; rm -rf libgnc-module.so.0 )
( cd usr/lib ; ln -sf libgnc-module.so.0.0.0 libgnc-module.so.0 )
( cd usr/lib/gnucash ; rm -rf libgncmod-qif.so )
( cd usr/lib/gnucash ; ln -sf libgncmod-qif.so.0.0.0 libgncmod-qif.so )
( cd usr/lib/gnucash ; rm -rf libgncmod-qif.so.0 )
( cd usr/lib/gnucash ; ln -sf libgncmod-qif.so.0.0.0 libgncmod-qif.so.0 )
( cd usr/lib ; rm -rf libgnc-core-utils.so )
( cd usr/lib ; ln -sf libgnc-core-utils.so.0.0.0 libgnc-core-utils.so )
( cd usr/lib ; rm -rf libgnc-backend-file-utils.so )
( cd usr/lib ; ln -sf libgnc-backend-file-utils.so.0.0.0 libgnc-backend-file-utils.so )
( cd usr/lib ; rm -rf libgnc-gnome.so )
( cd usr/lib ; ln -sf libgnc-gnome.so.0.0.0 libgnc-gnome.so )
( cd usr/lib ; rm -rf libgnc-module.so )
( cd usr/lib ; ln -sf libgnc-module.so.0.0.0 libgnc-module.so )
( cd usr/lib ; rm -rf libgnc-business-ledger.so )
( cd usr/lib ; ln -sf libgnc-business-ledger.so.0.0.0 libgnc-business-ledger.so )
( cd usr/lib ; rm -rf libgnc-qof.so.1 )
( cd usr/lib ; ln -sf libgnc-qof.so.1.0.4 libgnc-qof.so.1 )
( cd usr/lib ; rm -rf libgnc-backend-file-utils.so.0 )
( cd usr/lib ; ln -sf libgnc-backend-file-utils.so.0.0.0 libgnc-backend-file-utils.so.0 )
( cd usr/lib ; rm -rf libgnc-qof.so )
( cd usr/lib ; ln -sf libgnc-qof.so.1.0.4 libgnc-qof.so )
( cd usr/lib ; rm -rf libgnc-gnome.so.0 )
( cd usr/lib ; ln -sf libgnc-gnome.so.0.0.0 libgnc-gnome.so.0 )
( cd usr/lib ; rm -rf libgnc-core-utils.so.0 )
( cd usr/lib ; ln -sf libgnc-core-utils.so.0.0.0 libgnc-core-utils.so.0 )
( cd usr/share/gnucash ; rm -rf gnome )
( cd usr/share/gnucash ; ln -sf ../gnome gnome )

==> gnucash-2.3.2-i486-1sys.tgz: install/doinst.sh <==
if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database /usr/share/mime &> /dev/null
fi

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database &> /dev/null
fi

if [ -x /usr/bin/gtk-update-icon-cache ]; then
  /usr/bin/gtk-update-icon-cache  -f -q /usr/share/icons/hicolor &> /dev/null
fi
	# Update the scrollkeeper database (Remove stale pieces)
	if [ -x usr/bin/scrollkeeper-update ]; then
		usr/bin/scrollkeeper-update > /dev/null 2>&1
	fi
#
( cd usr/share/gnucash ; rm -rf gnome )
( cd usr/share/gnucash ; ln -sf ../gnome gnome )
( cd usr/lib ; rm -rf libgnc-backend-sql.so )
( cd usr/lib ; ln -sf libgnc-backend-sql.so.0.0.0 libgnc-backend-sql.so )
( cd usr/lib ; rm -rf libgnc-core-utils.so )
( cd usr/lib ; ln -sf libgnc-core-utils.so.0.0.0 libgnc-core-utils.so )
( cd usr/lib ; rm -rf libgnc-qof.so )
( cd usr/lib ; ln -sf libgnc-qof.so.1.0.4 libgnc-qof.so )
( cd usr/lib ; rm -rf libgnc-module.so.0 )
( cd usr/lib ; ln -sf libgnc-module.so.0.0.0 libgnc-module.so.0 )
( cd usr/lib ; rm -rf libgnc-backend-xml-utils.so )
( cd usr/lib ; ln -sf libgnc-backend-xml-utils.so.0.0.0 libgnc-backend-xml-utils.so )
( cd usr/lib ; rm -rf libgnc-backend-sql.so.0 )
( cd usr/lib ; ln -sf libgnc-backend-sql.so.0.0.0 libgnc-backend-sql.so.0 )
( cd usr/lib ; rm -rf libgnc-backend-xml-utils.so.0 )
( cd usr/lib ; ln -sf libgnc-backend-xml-utils.so.0.0.0 libgnc-backend-xml-utils.so.0 )
( cd usr/lib ; rm -rf libgnc-business-ledger.so )
( cd usr/lib ; ln -sf libgnc-business-ledger.so.0.0.0 libgnc-business-ledger.so )
( cd usr/lib ; rm -rf libgnc-qof.so.1 )
( cd usr/lib ; ln -sf libgnc-qof.so.1.0.4 libgnc-qof.so.1 )
( cd usr/lib ; rm -rf libgnc-gnome.so.0 )
( cd usr/lib ; ln -sf libgnc-gnome.so.0.0.0 libgnc-gnome.so.0 )
( cd usr/lib/gnucash ; rm -rf libgncmod-qif.so.0 )
( cd usr/lib/gnucash ; ln -sf libgncmod-qif.so.0.0.0 libgncmod-qif.so.0 )
( cd usr/lib/gnucash ; rm -rf libgncmod-qif.so )
( cd usr/lib/gnucash ; ln -sf libgncmod-qif.so.0.0.0 libgncmod-qif.so )
( cd usr/lib ; rm -rf libgnc-business-ledger.so.0 )
( cd usr/lib ; ln -sf libgnc-business-ledger.so.0.0.0 libgnc-business-ledger.so.0 )
( cd usr/lib ; rm -rf libgnc-core-utils.so.0 )
( cd usr/lib ; ln -sf libgnc-core-utils.so.0.0.0 libgnc-core-utils.so.0 )
( cd usr/lib ; rm -rf libgnc-module.so )
( cd usr/lib ; ln -sf libgnc-module.so.0.0.0 libgnc-module.so )
( cd usr/lib ; rm -rf libgnc-gnome.so )
( cd usr/lib ; ln -sf libgnc-gnome.so.0.0.0 libgnc-gnome.so )
